@@ -1,5 +1,3 @@
-//go:build !sqlite
-
 // SPDX-FileCopyrightText: Copyright The Miniflux Authors. All rights reserved.
 // SPDX-License-Identifier: Apache-2.0
 
@@ -25,7 +23,3 @@ func NewConnectionPool(dsn string, minConnections, maxConnections int, connectio
 
 	return db, nil
 }
-
-func getDriverStr() string {
-	return "postgresql"
-}
