@@ -5,20 +5,20 @@ package subscription // import "miniflux.app/v2/internal/reader/subscription"
 
 import "fmt"
 
-// Subscription represents a feed subscription.
-type Subscription struct {
+// subscription represents a feed subscription.
+type subscription struct {
 	Title string `json:"title"`
 	URL   string `json:"url"`
 	Type  string `json:"type"`
 }
 
-func NewSubscription(title, url, kind string) *Subscription {
-	return &Subscription{Title: title, URL: url, Type: kind}
+func NewSubscription(title, url, kind string) *subscription {
+	return &subscription{Title: title, URL: url, Type: kind}
 }
 
-func (s Subscription) String() string {
+func (s subscription) String() string {
 	return fmt.Sprintf(`Title=%q, URL=%q, Type=%q`, s.Title, s.URL, s.Type)
 }
 
 // Subscriptions represents a list of subscription.
-type Subscriptions []*Subscription
+type Subscriptions []*subscription
