@@ -8,8 +8,6 @@ import (
 	"errors"
 	"fmt"
 	"log/slog"
-	"slices"
-	"strings"
 	"time"
 
 	"miniflux.app/v2/internal/crypto"
@@ -71,6 +69,7 @@ func (s *Storage) NewEntryQueryBuilder(userID int64) *EntryQueryBuilder {
 
 // UpdateEntryTitleAndContent updates entry title and content.
 func (s *Storage) UpdateEntryTitleAndContent(entry *model.Entry) error {
+	truncatedTitle, truncatedContent := truncateTitleAndContentForTSVectorField(entry.Title, entry.Content)
 	query := `
 		UPDATE
 			entries
@@ -78,12 +77,20 @@ func (s *Storage) UpdateEntryTitleAndContent(entry *model.Entry) error {
 			title=$1,
 			content=$2,
 			reading_time=$3,
-			document_vectors = setweight(to_tsvector(left(coalesce($1, ''), 500000)), 'A') || setweight(to_tsvector(left(coalesce($2, ''), 500000)), 'B')
+			document_vectors = setweight(to_tsvector($4), 'A') || setweight(to_tsvector($5), 'B')
 		WHERE
-			id=$4 AND user_id=$5
+			id=$6 AND user_id=$7
 	`
 
-	if _, err := s.db.Exec(query, entry.Title, entry.Content, entry.ReadingTime, entry.ID, entry.UserID); err != nil {
+	if _, err := s.db.Exec(
+		query,
+		entry.Title,
+		entry.Content,
+		entry.ReadingTime,
+		truncatedTitle,
+		truncatedContent,
+		entry.ID,
+		entry.UserID); err != nil {
 		return fmt.Errorf(`store: unable to update entry #%d: %v`, entry.ID, err)
 	}
 
@@ -92,6 +99,7 @@ func (s *Storage) UpdateEntryTitleAndContent(entry *model.Entry) error {
 
 // createEntry add a new entry.
 func (s *Storage) createEntry(tx *sql.Tx, entry *model.Entry) error {
+	truncatedTitle, truncatedContent := truncateTitleAndContentForTSVectorField(entry.Title, entry.Content)
 	query := `
 		INSERT INTO entries
 			(
@@ -122,8 +130,8 @@ func (s *Storage) createEntry(tx *sql.Tx, entry *model.Entry) error {
 				$9,
 				$10,
 				now(),
-				setweight(to_tsvector(left(coalesce($1, ''), 500000)), 'A') || setweight(to_tsvector(left(coalesce($6, ''), 500000)), 'B'),
-				$11
+				setweight(to_tsvector($11), 'A') || setweight(to_tsvector($12), 'B'),
+				$13
 			)
 		RETURNING
 			id, status, created_at, changed_at
@@ -140,14 +148,15 @@ func (s *Storage) createEntry(tx *sql.Tx, entry *model.Entry) error {
 		entry.UserID,
 		entry.FeedID,
 		entry.ReadingTime,
-		pq.Array(removeEmpty(removeDuplicates(entry.Tags))),
+		truncatedTitle,
+		truncatedContent,
+		pq.Array(entry.Tags),
 	).Scan(
 		&entry.ID,
 		&entry.Status,
 		&entry.CreatedAt,
 		&entry.ChangedAt,
 	)
-
 	if err != nil {
 		return fmt.Errorf(`store: unable to create entry %q (feed #%d): %v`, entry.URL, entry.FeedID, err)
 	}
@@ -168,6 +177,7 @@ func (s *Storage) createEntry(tx *sql.Tx, entry *model.Entry) error {
 // Note: we do not update the published date because some feeds do not contains any date,
 // it default to time.Now() which could change the order of items on the history page.
 func (s *Storage) updateEntry(tx *sql.Tx, entry *model.Entry) error {
+	truncatedTitle, truncatedContent := truncateTitleAndContentForTSVectorField(entry.Title, entry.Content)
 	query := `
 		UPDATE
 			entries
@@ -178,10 +188,10 @@ func (s *Storage) updateEntry(tx *sql.Tx, entry *model.Entry) error {
 			content=$4,
 			author=$5,
 			reading_time=$6,
-			document_vectors = setweight(to_tsvector(left(coalesce($1, ''), 500000)), 'A') || setweight(to_tsvector(left(coalesce($4, ''), 500000)), 'B'),
-			tags=$10
+			document_vectors = setweight(to_tsvector($7), 'A') || setweight(to_tsvector($8), 'B'),
+			tags=$12
 		WHERE
-			user_id=$7 AND feed_id=$8 AND hash=$9
+			user_id=$9 AND feed_id=$10 AND hash=$11
 		RETURNING
 			id
 	`
@@ -193,12 +203,13 @@ func (s *Storage) updateEntry(tx *sql.Tx, entry *model.Entry) error {
 		entry.Content,
 		entry.Author,
 		entry.ReadingTime,
+		truncatedTitle,
+		truncatedContent,
 		entry.UserID,
 		entry.FeedID,
 		entry.Hash,
-		pq.Array(removeEmpty(removeDuplicates(entry.Tags))),
+		pq.Array(entry.Tags),
 	).Scan(&entry.ID)
-
 	if err != nil {
 		return fmt.Errorf(`store: unable to update entry %q: %v`, entry.URL, err)
 	}
@@ -216,7 +227,7 @@ func (s *Storage) entryExists(tx *sql.Tx, entry *model.Entry) (bool, error) {
 	var result bool
 
 	// Note: This query uses entries_feed_id_hash_key index (filtering on user_id is not necessary).
-	err := tx.QueryRow(`SELECT true FROM entries WHERE feed_id=$1 AND hash=$2`, entry.FeedID, entry.Hash).Scan(&result)
+	err := tx.QueryRow(`SELECT true FROM entries WHERE feed_id=$1 AND hash=$2 LIMIT 1`, entry.FeedID, entry.Hash).Scan(&result)
 
 	if err != nil && err != sql.ErrNoRows {
 		return result, fmt.Errorf(`store: unable to check if entry exists: %v`, err)
@@ -225,9 +236,61 @@ func (s *Storage) entryExists(tx *sql.Tx, entry *model.Entry) (bool, error) {
 	return result, nil
 }
 
+func (s *Storage) getEntryIDByHash(tx *sql.Tx, feedID int64, entryHash string) (int64, error) {
+    var entryID int64
+
+    err := tx.QueryRow(
+        `SELECT id FROM entries WHERE feed_id=$1 AND hash=$2 LIMIT 1`,
+        feedID,
+        entryHash,
+    ).Scan(&entryID)
+
+    if err != nil {
+        return 0, fmt.Errorf(`store: unable to fetch entry ID: %v`, err)
+    }
+
+    return entryID, nil
+}
+
+// InsertEntryForFeed inserts a single entry into a feed, optionally updating if it already exists.
+// Returns true if a new entry was created, false if an existing one was reused.
+func (s *Storage) InsertEntryForFeed(userID, feedID int64, entry *model.Entry) (bool, error) {
+	entry.UserID = userID
+    entry.FeedID = feedID
+
+    tx, err := s.db.Begin()
+    if err != nil {
+        return false, fmt.Errorf("store: unable to start transaction: %v", err)
+    }
+	defer tx.Rollback()
+
+	exists, err := s.entryExists(tx, entry)
+	if err != nil {
+    	return false, err
+	}
+
+	if exists {
+    	entryID, err := s.getEntryIDByHash(tx, entry.FeedID, entry.Hash)
+    	if err != nil {
+        	return false, err
+    	}
+    	entry.ID = entryID
+	} else {
+    	if err := s.createEntry(tx, entry); err != nil {
+        	return false, err
+    	}
+	}
+
+    if err := tx.Commit(); err != nil {
+        return false, err
+    }
+
+    return !exists, nil
+}
+
 func (s *Storage) IsNewEntry(feedID int64, entryHash string) bool {
 	var result bool
-	s.db.QueryRow(`SELECT true FROM entries WHERE feed_id=$1 AND hash=$2`, feedID, entryHash).Scan(&result)
+	s.db.QueryRow(`SELECT true FROM entries WHERE feed_id=$1 AND hash=$2 LIMIT 1`, feedID, entryHash).Scan(&result)
 	return !result
 }
 
@@ -250,8 +313,8 @@ func (s *Storage) GetReadTime(feedID int64, entryHash string) int {
 	return result
 }
 
-// cleanupEntries deletes from the database entries marked as "removed" and not visible anymore in the feed.
-func (s *Storage) cleanupEntries(feedID int64, entryHashes []string) error {
+// cleanupRemovedEntriesNotInFeed deletes from the database entries marked as "removed" and not visible anymore in the feed.
+func (s *Storage) cleanupRemovedEntriesNotInFeed(feedID int64, entryHashes []string) error {
 	query := `
 		DELETE FROM
 			entries
@@ -267,9 +330,64 @@ func (s *Storage) cleanupEntries(feedID int64, entryHashes []string) error {
 	return nil
 }
 
+// DeleteRemovedEntriesEnclosures deletes enclosures associated with entries marked as "removed".
+func (s *Storage) DeleteRemovedEntriesEnclosures() (int64, error) {
+	query := `
+		DELETE FROM
+			enclosures
+		WHERE
+		 	enclosures.entry_id IN (SELECT id FROM entries WHERE status=$1)
+	`
+	result, err := s.db.Exec(query, model.EntryStatusRemoved)
+	if err != nil {
+		return 0, fmt.Errorf(`store: unable to delete enclosures from removed entries: %v`, err)
+	}
+
+	count, err := result.RowsAffected()
+	if err != nil {
+		return 0, fmt.Errorf(`store: unable to get the number of rows affected while deleting enclosures from removed entries: %v`, err)
+	}
+
+	return count, nil
+}
+
+// ClearRemovedEntriesContent clears the content fields of entries marked as "removed", keeping only their metadata.
+func (s *Storage) ClearRemovedEntriesContent(limit int) (int64, error) {
+	query := `
+		UPDATE
+			entries
+		SET
+			title='',
+			content=NULL,
+			url='',
+			author=NULL,
+			comments_url=NULL,
+			document_vectors=NULL
+		WHERE id IN (
+			SELECT id
+			FROM entries
+			WHERE status = $1 AND content IS NOT NULL
+			ORDER BY id ASC
+			LIMIT $2
+		)
+	`
+
+	result, err := s.db.Exec(query, model.EntryStatusRemoved, limit)
+	if err != nil {
+		return 0, fmt.Errorf(`store: unable to clear content from removed entries: %v`, err)
+	}
+
+	count, err := result.RowsAffected()
+	if err != nil {
+		return 0, fmt.Errorf(`store: unable to get the number of rows affected while clearing content from removed entries: %v`, err)
+	}
+
+	return count, nil
+}
+
 // RefreshFeedEntries updates feed entries while refreshing a feed.
 func (s *Storage) RefreshFeedEntries(userID, feedID int64, entries model.Entries, updateExistingEntries bool) (newEntries model.Entries, err error) {
-	var entryHashes []string
+	entryHashes := make([]string, 0, len(entries))
 
 	for _, entry := range entries {
 		entry.UserID = userID
@@ -314,8 +432,8 @@ func (s *Storage) RefreshFeedEntries(userID, feedID int64, entries model.Entries
 	}
 
 	go func() {
-		if err := s.cleanupEntries(feedID, entryHashes); err != nil {
-			slog.Error("Unable to cleanup entries",
+		if err := s.cleanupRemovedEntriesNotInFeed(feedID, entryHashes); err != nil {
+			slog.Error("Unable to cleanup removed entries",
 				slog.Int64("user_id", userID),
 				slog.Int64("feed_id", feedID),
 				slog.Any("error", err),
@@ -326,9 +444,9 @@ func (s *Storage) RefreshFeedEntries(userID, feedID int64, entries model.Entries
 	return newEntries, nil
 }
 
-// ArchiveEntries changes the status of entries to "removed" after the given number of days.
-func (s *Storage) ArchiveEntries(status string, days, limit int) (int64, error) {
-	if days < 0 || limit <= 0 {
+// ArchiveEntries changes the status of entries to "removed" after the interval (24h minimum).
+func (s *Storage) ArchiveEntries(status string, interval time.Duration, limit int) (int64, error) {
+	if interval < 0 || limit <= 0 {
 		return 0, nil
 	}
 
@@ -353,6 +471,8 @@ func (s *Storage) ArchiveEntries(status string, days, limit int) (int64, error)
 				)
 	`
 
+	days := max(int(interval/(24*time.Hour)), 1)
+
 	result, err := s.db.Exec(query, model.EntryStatusRemoved, status, fmt.Sprintf("%d days", days), limit)
 	if err != nil {
 		return 0, fmt.Errorf(`store: unable to archive %s entries: %v`, status, err)
@@ -368,8 +488,19 @@ func (s *Storage) ArchiveEntries(status string, days, limit int) (int64, error)
 
 // SetEntriesStatus update the status of the given list of entries.
 func (s *Storage) SetEntriesStatus(userID int64, entryIDs []int64, status string) error {
-	query := `UPDATE entries SET status=$1, changed_at=now() WHERE user_id=$2 AND id=ANY($3)`
-	if _, err := s.db.Exec(query, status, userID, pq.Array(entryIDs)); err != nil {
+	// Entries that have the model.EntryStatusRemoved status are immutable.
+	query := `
+		UPDATE
+			entries
+		SET
+			status=$1,
+			changed_at=now()
+		WHERE
+			user_id=$2 AND
+			id=ANY($3) AND
+			status!=$4
+		`
+	if _, err := s.db.Exec(query, status, userID, pq.Array(entryIDs), model.EntryStatusRemoved); err != nil {
 		return fmt.Errorf(`store: unable to update entries statuses %v: %v`, entryIDs, err)
 	}
 
@@ -400,12 +531,12 @@ func (s *Storage) SetEntriesStatusCount(userID int64, entryIDs []int64, status s
 	return visible, nil
 }
 
-// SetEntriesBookmarked update the bookmarked state for the given list of entries.
-func (s *Storage) SetEntriesBookmarkedState(userID int64, entryIDs []int64, starred bool) error {
+// SetEntriesStarredState updates the starred state for the given list of entries.
+func (s *Storage) SetEntriesStarredState(userID int64, entryIDs []int64, starred bool) error {
 	query := `UPDATE entries SET starred=$1, changed_at=now() WHERE user_id=$2 AND id=ANY($3)`
 	result, err := s.db.Exec(query, starred, userID, pq.Array(entryIDs))
 	if err != nil {
-		return fmt.Errorf(`store: unable to update the bookmarked state %v: %v`, entryIDs, err)
+		return fmt.Errorf(`store: unable to update the starred state %v: %v`, entryIDs, err)
 	}
 
 	count, err := result.RowsAffected()
@@ -420,17 +551,17 @@ func (s *Storage) SetEntriesBookmarkedState(userID int64, entryIDs []int64, star
 	return nil
 }
 
-// ToggleBookmark toggles entry bookmark value.
-func (s *Storage) ToggleBookmark(userID int64, entryID int64) error {
+// ToggleStarred toggles entry starred value.
+func (s *Storage) ToggleStarred(userID int64, entryID int64) error {
 	query := `UPDATE entries SET starred = NOT starred, changed_at=now() WHERE user_id=$1 AND id=$2`
 	result, err := s.db.Exec(query, userID, entryID)
 	if err != nil {
-		return fmt.Errorf(`store: unable to toggle bookmark flag for entry #%d: %v`, entryID, err)
+		return fmt.Errorf(`store: unable to toggle starred flag for entry #%d: %v`, entryID, err)
 	}
 
 	count, err := result.RowsAffected()
 	if err != nil {
-		return fmt.Errorf(`store: unable to toggle bookmark flag for entry #%d: %v`, entryID, err)
+		return fmt.Errorf(`store: unable to toggle starred flag for entry #%d: %v`, entryID, err)
 	}
 
 	if count == 0 {
@@ -628,17 +759,33 @@ func (s *Storage) UnshareEntry(userID int64, entryID int64) (err error) {
 	return
 }
 
-func removeDuplicates(l []string) []string {
-	slices.Sort(l)
-	return slices.Compact(l)
+func truncateTitleAndContentForTSVectorField(title, content string) (string, string) {
+	// The length of a tsvector (lexemes + positions) must be less than 1 megabyte.
+	// We don't need to index the entire content, and we need to keep a buffer for the positions.
+	return truncateStringForTSVectorField(title, 200000), truncateStringForTSVectorField(content, 500000)
 }
 
-func removeEmpty(l []string) []string {
-	var finalSlice []string
-	for _, item := range l {
-		if strings.TrimSpace(item) != "" {
-			finalSlice = append(finalSlice, item)
+// truncateStringForTSVectorField truncates a string and don't break UTF-8 characters.
+func truncateStringForTSVectorField(s string, maxSize int) string {
+	if len(s) < maxSize {
+		return s
+	}
+
+	// Truncate to fit under the limit, ensuring we don't break UTF-8 characters
+	truncated := s[:maxSize-1]
+
+	// Walk backwards to find the last complete UTF-8 character
+	for i := len(truncated) - 1; i >= 0; i-- {
+		if (truncated[i] & 0x80) == 0 {
+			// ASCII character, we can stop here
+			return truncated[:i+1]
+		}
+		if (truncated[i] & 0xC0) == 0xC0 {
+			// Start of a multi-byte UTF-8 character
+			return truncated[:i]
 		}
 	}
-	return finalSlice
+
+	// Fallback: return empty string if we can't find a valid UTF-8 boundary
+	return ""
 }
