@@ -164,6 +164,7 @@ func (s *Storage) Integration(userID int64) (*model.Integration, error) {
 			linkwarden_enabled,
 			linkwarden_url,
 			linkwarden_api_key,
+			linkwarden_collection_id,
 			matrix_bot_enabled,
 			matrix_bot_user,
 			matrix_bot_password,
@@ -177,6 +178,7 @@ func (s *Storage) Integration(userID int64) (*model.Integration, error) {
 			readeck_api_key,
 			readeck_labels,
 			readeck_only_url,
+			readeck_push_enabled,
 			shiori_enabled,
 			shiori_url,
 			shiori_username,
@@ -291,6 +293,7 @@ func (s *Storage) Integration(userID int64) (*model.Integration, error) {
 		&integration.LinkwardenEnabled,
 		&integration.LinkwardenURL,
 		&integration.LinkwardenAPIKey,
+		&integration.LinkwardenCollectionID,
 		&integration.MatrixBotEnabled,
 		&integration.MatrixBotUser,
 		&integration.MatrixBotPassword,
@@ -304,6 +307,7 @@ func (s *Storage) Integration(userID int64) (*model.Integration, error) {
 		&integration.ReadeckAPIKey,
 		&integration.ReadeckLabels,
 		&integration.ReadeckOnlyURL,
+		&integration.ReadeckPushEnabled,
 		&integration.ShioriEnabled,
 		&integration.ShioriURL,
 		&integration.ShioriUsername,
@@ -491,9 +495,11 @@ func (s *Storage) UpdateIntegration(integration *model.Integration) error {
 			linktaco_org_slug=$116,
 			linktaco_tags=$117,
 			linktaco_visibility=$118,
-			archiveorg_enabled=$119
+			archiveorg_enabled=$119,
+			linkwarden_collection_id=$120,
+			readeck_push_enabled=$121
 		WHERE
-			user_id=$120
+			user_id=$122
 	`
 	_, err := s.db.Exec(
 		query,
@@ -616,6 +622,8 @@ func (s *Storage) UpdateIntegration(integration *model.Integration) error {
 		integration.LinktacoTags,
 		integration.LinktacoVisibility,
 		integration.ArchiveorgEnabled,
+		integration.LinkwardenCollectionID,
+		integration.ReadeckPushEnabled,
 		integration.UserID,
 	)
 
