@@ -15,19 +15,13 @@ func (h *handler) markFeedAsRead(w http.ResponseWriter, r *http.Request) {
 	feedID := request.RouteInt64Param(r, "feedID")
 	userID := request.UserID(r)
 
-	feed, err := h.store.FeedByID(userID, feedID)
-
+	checkedAt, err := h.store.CheckedAt(userID, feedID)
 	if err != nil {
-		html.ServerError(w, r, err)
-		return
-	}
-
-	if feed == nil {
 		html.NotFound(w, r)
 		return
 	}
 
-	if err = h.store.MarkFeedAsRead(userID, feedID, feed.CheckedAt); err != nil {
+	if err = h.store.MarkFeedAsRead(userID, feedID, checkedAt); err != nil {
 		html.ServerError(w, r, err)
 		return
 	}
