@@ -8,6 +8,7 @@ import (
 	"errors"
 	"log/slog"
 	"net/http"
+	"net/url"
 
 	"miniflux.app/v2/internal/config"
 	"miniflux.app/v2/internal/crypto"
@@ -42,7 +43,11 @@ func (m *middleware) handleUserSession(next http.Handler) http.Handler {
 				slog.Debug("Redirecting to login page because no user session has been found",
 					slog.String("url", r.RequestURI),
 				)
-				html.Redirect(w, r, route.Path(m.router, "login"))
+				loginURL, _ := url.Parse(route.Path(m.router, "login"))
+				values := loginURL.Query()
+				values.Set("redirect_url", r.RequestURI)
+				loginURL.RawQuery = values.Encode()
+				html.Redirect(w, r, loginURL.String())
 			}
 		} else {
 			slog.Debug("User session found",
@@ -201,6 +206,19 @@ func (m *middleware) handleAuthProxy(next http.Handler) http.Handler {
 			return
 		}
 
+		remoteIP := request.FindRemoteIP(r)
+		trustedNetworks := config.Opts.TrustedReverseProxyNetworks()
+		if !request.IsTrustedIP(remoteIP, trustedNetworks) {
+			slog.Warn("[AuthProxy] Rejecting authentication request from untrusted proxy",
+				slog.String("remote_ip", remoteIP),
+				slog.String("client_ip", request.ClientIP(r)),
+				slog.String("user_agent", r.UserAgent()),
+				slog.Any("trusted_networks", trustedNetworks),
+			)
+			next.ServeHTTP(w, r)
+			return
+		}
+
 		username := r.Header.Get(config.Opts.AuthProxyHeader())
 		if username == "" {
 			next.ServeHTTP(w, r)
@@ -210,6 +228,7 @@ func (m *middleware) handleAuthProxy(next http.Handler) http.Handler {
 		clientIP := request.ClientIP(r)
 		slog.Debug("[AuthProxy] Received authenticated requested",
 			slog.String("client_ip", clientIP),
+			slog.String("remote_ip", remoteIP),
 			slog.String("user_agent", r.UserAgent()),
 			slog.String("username", username),
 		)
@@ -225,6 +244,7 @@ func (m *middleware) handleAuthProxy(next http.Handler) http.Handler {
 				slog.Debug("[AuthProxy] User doesn't exist and user creation is not allowed",
 					slog.Bool("authentication_failed", true),
 					slog.String("client_ip", clientIP),
+					slog.String("remote_ip", remoteIP),
 					slog.String("user_agent", r.UserAgent()),
 					slog.String("username", username),
 				)
@@ -247,6 +267,7 @@ func (m *middleware) handleAuthProxy(next http.Handler) http.Handler {
 		slog.Info("[AuthProxy] User authenticated successfully",
 			slog.Bool("authentication_successful", true),
 			slog.String("client_ip", clientIP),
+			slog.String("remote_ip", remoteIP),
 			slog.String("user_agent", r.UserAgent()),
 			slog.Int64("user_id", user.ID),
 			slog.String("username", user.Username),
