@@ -22,6 +22,7 @@ import (
 	"miniflux.app/v2/internal/http/response/html"
 	"miniflux.app/v2/internal/reader/fetcher"
 	"miniflux.app/v2/internal/reader/rewrite"
+	"miniflux.app/v2/internal/urllib"
 )
 
 func (h *handler) mediaProxy(w http.ResponseWriter, r *http.Request) {
@@ -81,6 +82,24 @@ func (h *handler) mediaProxy(w http.ResponseWriter, r *http.Request) {
 	}
 
 	mediaURL := string(decodedURL)
+
+	if !config.Opts.MediaProxyAllowPrivateNetworks() {
+		if isPrivate, err := urllib.ResolvesToPrivateIP(parsedMediaURL.Hostname()); err != nil {
+			slog.Warn("MediaProxy: Unable to resolve hostname",
+				slog.String("media_url", mediaURL),
+				slog.Any("error", err),
+			)
+			html.Forbidden(w, r)
+			return
+		} else if isPrivate {
+			slog.Warn("MediaProxy: Refusing to access private IP address",
+				slog.String("media_url", mediaURL),
+			)
+			html.Forbidden(w, r)
+			return
+		}
+	}
+
 	slog.Debug("MediaProxy: Fetching remote resource",
 		slog.String("media_url", mediaURL),
 	)
