@@ -10,6 +10,7 @@ import (
 	"miniflux.app/v2/internal/http/response/html"
 	"miniflux.app/v2/internal/locale"
 	"miniflux.app/v2/internal/model"
+	"miniflux.app/v2/internal/timezone"
 	"miniflux.app/v2/internal/ui/form"
 	"miniflux.app/v2/internal/ui/session"
 	"miniflux.app/v2/internal/ui/view"
@@ -23,36 +24,31 @@ func (h *handler) showSettingsPage(w http.ResponseWriter, r *http.Request) {
 	}
 
 	settingsForm := form.SettingsForm{
-		Username:                user.Username,
-		Theme:                   user.Theme,
-		Language:                user.Language,
-		Timezone:                user.Timezone,
-		EntryDirection:          user.EntryDirection,
-		EntryOrder:              user.EntryOrder,
-		EntriesPerPage:          user.EntriesPerPage,
-		KeyboardShortcuts:       user.KeyboardShortcuts,
-		ShowReadingTime:         user.ShowReadingTime,
-		CustomCSS:               user.Stylesheet,
-		CustomJS:                user.CustomJS,
-		ExternalFontHosts:       user.ExternalFontHosts,
-		EntrySwipe:              user.EntrySwipe,
-		GestureNav:              user.GestureNav,
-		DisplayMode:             user.DisplayMode,
-		DefaultReadingSpeed:     user.DefaultReadingSpeed,
-		CJKReadingSpeed:         user.CJKReadingSpeed,
-		DefaultHomePage:         user.DefaultHomePage,
-		CategoriesSortingOrder:  user.CategoriesSortingOrder,
-		MarkReadBehavior:        form.MarkAsReadBehavior(user.MarkReadOnView, user.MarkReadOnMediaPlayerCompletion),
-		MediaPlaybackRate:       user.MediaPlaybackRate,
-		BlockFilterEntryRules:   user.BlockFilterEntryRules,
-		KeepFilterEntryRules:    user.KeepFilterEntryRules,
-		AlwaysOpenExternalLinks: user.AlwaysOpenExternalLinks,
-	}
-
-	timezones, err := h.store.Timezones()
-	if err != nil {
-		html.ServerError(w, r, err)
-		return
+		Username:                  user.Username,
+		Theme:                     user.Theme,
+		Language:                  user.Language,
+		Timezone:                  user.Timezone,
+		EntryDirection:            user.EntryDirection,
+		EntryOrder:                user.EntryOrder,
+		EntriesPerPage:            user.EntriesPerPage,
+		KeyboardShortcuts:         user.KeyboardShortcuts,
+		ShowReadingTime:           user.ShowReadingTime,
+		CustomCSS:                 user.Stylesheet,
+		CustomJS:                  user.CustomJS,
+		ExternalFontHosts:         user.ExternalFontHosts,
+		EntrySwipe:                user.EntrySwipe,
+		GestureNav:                user.GestureNav,
+		DisplayMode:               user.DisplayMode,
+		DefaultReadingSpeed:       user.DefaultReadingSpeed,
+		CJKReadingSpeed:           user.CJKReadingSpeed,
+		DefaultHomePage:           user.DefaultHomePage,
+		CategoriesSortingOrder:    user.CategoriesSortingOrder,
+		MarkReadBehavior:          form.MarkAsReadBehavior(user.MarkReadOnView, user.MarkReadOnMediaPlayerCompletion),
+		MediaPlaybackRate:         user.MediaPlaybackRate,
+		BlockFilterEntryRules:     user.BlockFilterEntryRules,
+		KeepFilterEntryRules:      user.KeepFilterEntryRules,
+		AlwaysOpenExternalLinks:   user.AlwaysOpenExternalLinks,
+		OpenExternalLinksInNewTab: user.OpenExternalLinksInNewTab,
 	}
 
 	creds, err := h.store.WebAuthnCredentialsByUserID(user.ID)
@@ -72,7 +68,7 @@ func (h *handler) showSettingsPage(w http.ResponseWriter, r *http.Request) {
 	})
 	view.Set("themes", model.Themes())
 	view.Set("languages", locale.AvailableLanguages)
-	view.Set("timezones", timezones)
+	view.Set("timezones", timezone.AvailableTimezones())
 	view.Set("menu", "settings")
 	view.Set("user", user)
 	view.Set("countUnread", h.store.CountUnreadEntries(user.ID))
