@@ -106,9 +106,11 @@ func (h *handler) submitSubscription(w http.ResponseWriter, r *http.Request) {
 				Password:                    subscriptionForm.Password,
 				ScraperRules:                subscriptionForm.ScraperRules,
 				RewriteRules:                subscriptionForm.RewriteRules,
+				UrlRewriteRules:             subscriptionForm.UrlRewriteRules,
 				BlocklistRules:              subscriptionForm.BlocklistRules,
 				KeeplistRules:               subscriptionForm.KeeplistRules,
-				UrlRewriteRules:             subscriptionForm.UrlRewriteRules,
+				KeepFilterEntryRules:        subscriptionForm.KeepFilterEntryRules,
+				BlockFilterEntryRules:       subscriptionForm.BlockFilterEntryRules,
 				FetchViaProxy:               subscriptionForm.FetchViaProxy,
 				DisableHTTP2:                subscriptionForm.DisableHTTP2,
 				ProxyURL:                    subscriptionForm.ProxyURL,
@@ -134,9 +136,11 @@ func (h *handler) submitSubscription(w http.ResponseWriter, r *http.Request) {
 			Password:                    subscriptionForm.Password,
 			ScraperRules:                subscriptionForm.ScraperRules,
 			RewriteRules:                subscriptionForm.RewriteRules,
+			UrlRewriteRules:             subscriptionForm.UrlRewriteRules,
 			BlocklistRules:              subscriptionForm.BlocklistRules,
 			KeeplistRules:               subscriptionForm.KeeplistRules,
-			UrlRewriteRules:             subscriptionForm.UrlRewriteRules,
+			KeepFilterEntryRules:        subscriptionForm.KeepFilterEntryRules,
+			BlockFilterEntryRules:       subscriptionForm.BlockFilterEntryRules,
 			FetchViaProxy:               subscriptionForm.FetchViaProxy,
 			DisableHTTP2:                subscriptionForm.DisableHTTP2,
 			ProxyURL:                    subscriptionForm.ProxyURL,
