@@ -14,5 +14,9 @@ func ValidateSubscriptionDiscovery(request *model.SubscriptionDiscoveryRequest)
 		return locale.NewLocalizedError("error.invalid_site_url")
 	}
 
+	if request.ProxyURL != "" && !IsValidURL(request.ProxyURL) {
+		return locale.NewLocalizedError("error.invalid_proxy_url")
+	}
+
 	return nil
 }
